@@ -17,4 +17,9 @@ pub mod cardinal_time_invalidator {
     pub fn invalidate<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
         invalidate::handler(ctx)
     }
+
+    pub fn close(ctx: Context<CloseCtx>) -> ProgramResult {
+        close::handler(ctx)
+    }
+
 }
\ No newline at end of file
